=============================================
 amqp - Python AMQP low-level client library
=============================================

.. include:: includes/intro.txt

Contents
========

.. toctree::
    :maxdepth: 2

    reference/index
    changelog

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

